==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dir_aebb8dcc11953d78e620bbef0b9e2183.js <==
var dir_aebb8dcc11953d78e620bbef0b9e2183 =
[
    [ "alloc_func.cpp", "d5/d51/alloc__func_8cpp.html", "d5/d51/alloc__func_8cpp" ],
    [ "alloc_func.hpp", "dc/dac/alloc__func_8hpp.html", "dc/dac/alloc__func_8hpp" ],
    [ "alloc_type.hpp", "d4/deb/alloc__type_8hpp.html", [
      [ "SmallStackSafeStackAlloc", "d7/d9c/structSmallStackSafeStackAlloc.html", "d7/d9c/structSmallStackSafeStackAlloc" ],
      [ "ReusableBuffer", "da/dc9/classReusableBuffer.html", "da/dc9/classReusableBuffer" ],
      [ "ZeroedMemoryAllocator", "d4/d27/classZeroedMemoryAllocator.html", "d4/d27/classZeroedMemoryAllocator" ],
      [ "AutoFreePtr", "d6/dd4/classAutoFreePtr.html", "d6/dd4/classAutoFreePtr" ]
    ] ],
    [ "backup_type.hpp", "d5/deb/backup__type_8hpp.html", [
      [ "Backup", "d4/d8c/structBackup.html", "d4/d8c/structBackup" ]
    ] ],
    [ "bitmath_func.cpp", "d6/dd0/bitmath__func_8cpp.html", "d6/dd0/bitmath__func_8cpp" ],
    [ "bitmath_func.hpp", "dc/d76/bitmath__func_8hpp.html", "dc/d76/bitmath__func_8hpp" ],
    [ "endian_func.hpp", "d5/d93/endian__func_8hpp.html", "d5/d93/endian__func_8hpp" ],
    [ "endian_type.hpp", "d7/dfd/endian__type_8hpp.html", "d7/dfd/endian__type_8hpp" ],
    [ "enum_type.hpp", "dc/deb/enum__type_8hpp.html", "dc/deb/enum__type_8hpp" ],
    [ "geometry_func.cpp", "d6/d10/geometry__func_8cpp.html", "d6/d10/geometry__func_8cpp" ],
    [ "geometry_func.hpp", "dc/d94/geometry__func_8hpp.html", "dc/d94/geometry__func_8hpp" ],
    [ "geometry_type.hpp", "da/d8e/geometry__type_8hpp.html", [
      [ "Point", "d8/d43/structPoint.html", "d8/d43/structPoint" ],
      [ "Dimension", "df/d12/structDimension.html", "df/d12/structDimension" ],
      [ "Rect", "db/d14/structRect.html", "db/d14/structRect" ],
      [ "PointDimension", "d1/df6/structPointDimension.html", "d1/df6/structPointDimension" ],
      [ "Pair", "de/dd5/structPair.html", "de/dd5/structPair" ]
    ] ],
    [ "math_func.cpp", "dc/d4a/math__func_8cpp.html", "dc/d4a/math__func_8cpp" ],
    [ "math_func.hpp", "d3/d09/math__func_8hpp.html", "d3/d09/math__func_8hpp" ],
    [ "mem_func.hpp", "da/d8a/mem__func_8hpp.html", "da/d8a/mem__func_8hpp" ],
    [ "multimap.hpp", "d6/dc8/multimap_8hpp.html", "d6/dc8/multimap_8hpp" ],
    [ "overflowsafe_type.hpp", "df/d61/overflowsafe__type_8hpp.html", "df/d61/overflowsafe__type_8hpp" ],
    [ "pool_func.cpp", "d8/de1/pool__func_8cpp.html", null ],
    [ "pool_func.hpp", "d3/dd5/pool__func_8hpp.html", "d3/dd5/pool__func_8hpp" ],
    [ "pool_type.hpp", "de/d3b/pool__type_8hpp.html", "de/d3b/pool__type_8hpp" ],
    [ "random_func.cpp", "db/d8a/random__func_8cpp.html", "db/d8a/random__func_8cpp" ],
    [ "random_func.hpp", "d8/dde/random__func_8hpp.html", "d8/dde/random__func_8hpp" ],
    [ "smallmap_type.hpp", "d2/d3e/smallmap__type_8hpp.html", [
      [ "SmallPair", "d5/d20/structSmallPair.html", "d5/d20/structSmallPair" ],
      [ "SmallMap", "d3/dd4/structSmallMap.html", "d3/dd4/structSmallMap" ]
    ] ],
    [ "smallmatrix_type.hpp", "da/d1c/smallmatrix__type_8hpp.html", [
      [ "SmallMatrix", "dc/dd5/classSmallMatrix.html", "dc/dd5/classSmallMatrix" ]
    ] ],
    [ "smallstack_type.hpp", "d7/def/smallstack__type_8hpp.html", [
      [ "SimplePool", "d5/df5/classSimplePool.html", "d5/df5/classSimplePool" ],
      [ "SimplePoolPoolItem", "dd/d83/structSimplePool_1_1SimplePoolPoolItem.html", "dd/d83/structSimplePool_1_1SimplePoolPoolItem" ],
      [ "SmallStackItem", "d6/da4/structSmallStackItem.html", "d6/da4/structSmallStackItem" ],
      [ "SmallStack", "d8/d98/classSmallStack.html", "d8/d98/classSmallStack" ],
      [ "PooledSmallStack", "db/d2f/structSmallStack_1_1PooledSmallStack.html", "db/d2f/structSmallStack_1_1PooledSmallStack" ]
    ] ],
    [ "smallvec_type.hpp", "df/dda/smallvec__type_8hpp.html", "df/dda/smallvec__type_8hpp" ],
    [ "sort_func.hpp", "d8/d39/sort__func_8hpp.html", "d8/d39/sort__func_8hpp" ],
    [ "string_compare_type.hpp", "d0/d26/string__compare__type_8hpp.html", [
      [ "StringCompare", "dd/d77/structStringCompare.html", "dd/d77/structStringCompare" ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dir_aebb8dcc11953d78e620bbef0b9e2183.js <==
var dir_aebb8dcc11953d78e620bbef0b9e2183 =
[
    [ "alloc_func.cpp", "d5/d51/alloc__func_8cpp.html", "d5/d51/alloc__func_8cpp" ],
    [ "alloc_func.hpp", "dc/dac/alloc__func_8hpp.html", "dc/dac/alloc__func_8hpp" ],
    [ "alloc_type.hpp", "d4/deb/alloc__type_8hpp.html", [
      [ "ReusableBuffer", "da/dc9/classReusableBuffer.html", "da/dc9/classReusableBuffer" ],
      [ "ZeroedMemoryAllocator", "d4/d27/classZeroedMemoryAllocator.html", "d4/d27/classZeroedMemoryAllocator" ]
    ] ],
    [ "backup_type.hpp", "d5/deb/backup__type_8hpp.html", [
      [ "Backup", "d4/d8c/structBackup.html", "d4/d8c/structBackup" ]
    ] ],
    [ "bitmath_func.cpp", "d6/dd0/bitmath__func_8cpp.html", "d6/dd0/bitmath__func_8cpp" ],
    [ "bitmath_func.hpp", "dc/d76/bitmath__func_8hpp.html", "dc/d76/bitmath__func_8hpp" ],
    [ "endian_func.hpp", "d5/d93/endian__func_8hpp.html", "d5/d93/endian__func_8hpp" ],
    [ "endian_type.hpp", "d7/dfd/endian__type_8hpp.html", "d7/dfd/endian__type_8hpp" ],
    [ "enum_type.hpp", "dc/deb/enum__type_8hpp.html", "dc/deb/enum__type_8hpp" ],
    [ "geometry_func.cpp", "d6/d10/geometry__func_8cpp.html", "d6/d10/geometry__func_8cpp" ],
    [ "geometry_func.hpp", "dc/d94/geometry__func_8hpp.html", "dc/d94/geometry__func_8hpp" ],
    [ "geometry_type.hpp", "da/d8e/geometry__type_8hpp.html", [
      [ "Point", "d8/d43/structPoint.html", "d8/d43/structPoint" ],
      [ "Dimension", "df/d12/structDimension.html", "df/d12/structDimension" ],
      [ "Rect", "db/d14/structRect.html", "db/d14/structRect" ],
      [ "PointDimension", "d1/df6/structPointDimension.html", "d1/df6/structPointDimension" ],
      [ "Pair", "de/dd5/structPair.html", "de/dd5/structPair" ]
    ] ],
    [ "kdtree.hpp", "d1/d3d/kdtree_8hpp.html", [
      [ "Kdtree", "d0/d01/classKdtree.html", "d0/d01/classKdtree" ],
      [ "node", "d8/dfd/structKdtree_1_1node.html", "d8/dfd/structKdtree_1_1node" ]
    ] ],
    [ "math_func.cpp", "dc/d4a/math__func_8cpp.html", "dc/d4a/math__func_8cpp" ],
    [ "math_func.hpp", "d3/d09/math__func_8hpp.html", "d3/d09/math__func_8hpp" ],
    [ "mem_func.hpp", "da/d8a/mem__func_8hpp.html", "da/d8a/mem__func_8hpp" ],
    [ "multimap.hpp", "d6/dc8/multimap_8hpp.html", "d6/dc8/multimap_8hpp" ],
    [ "overflowsafe_type.hpp", "df/d61/overflowsafe__type_8hpp.html", "df/d61/overflowsafe__type_8hpp" ],
    [ "pool_func.cpp", "d8/de1/pool__func_8cpp.html", null ],
    [ "pool_func.hpp", "d3/dd5/pool__func_8hpp.html", "d3/dd5/pool__func_8hpp" ],
    [ "pool_type.hpp", "de/d3b/pool__type_8hpp.html", "de/d3b/pool__type_8hpp" ],
    [ "random_func.cpp", "db/d8a/random__func_8cpp.html", "db/d8a/random__func_8cpp" ],
    [ "random_func.hpp", "d8/dde/random__func_8hpp.html", "d8/dde/random__func_8hpp" ],
    [ "smallmap_type.hpp", "d2/d3e/smallmap__type_8hpp.html", [
      [ "SmallMap", "d3/dd4/structSmallMap.html", "d3/dd4/structSmallMap" ]
    ] ],
    [ "smallmatrix_type.hpp", "da/d1c/smallmatrix__type_8hpp.html", [
      [ "SmallMatrix", "dc/dd5/classSmallMatrix.html", "dc/dd5/classSmallMatrix" ]
    ] ],
    [ "smallstack_type.hpp", "d7/def/smallstack__type_8hpp.html", [
      [ "SimplePool", "d5/df5/classSimplePool.html", "d5/df5/classSimplePool" ],
      [ "SimplePoolPoolItem", "dd/d83/structSimplePool_1_1SimplePoolPoolItem.html", "dd/d83/structSimplePool_1_1SimplePoolPoolItem" ],
      [ "SmallStackItem", "d6/da4/structSmallStackItem.html", "d6/da4/structSmallStackItem" ],
      [ "SmallStack", "d8/d98/classSmallStack.html", "d8/d98/classSmallStack" ],
      [ "PooledSmallStack", "db/d2f/structSmallStack_1_1PooledSmallStack.html", "db/d2f/structSmallStack_1_1PooledSmallStack" ]
    ] ],
    [ "smallvec_type.hpp", "df/dda/smallvec__type_8hpp.html", "df/dda/smallvec__type_8hpp" ],
    [ "string_compare_type.hpp", "d0/d26/string__compare__type_8hpp.html", [
      [ "StringCompare", "dd/d77/structStringCompare.html", "dd/d77/structStringCompare" ]
    ] ]
];
